==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Horný</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Dolný</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Ľavý</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Ľavý zadný</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Pravý</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Pravý zadný</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Otočiť výber proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Otočiť výber v smere hodinových ručičiek</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Mierka premietania v pôvodnej veľkosti (&apos;izometrický výkres&apos;)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Skutočná mierka</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Izometrický Pohľad</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Horný</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Dolný</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Ľavý</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Ľavý zadný</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Pravý</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Pravý zadný</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Otočiť výber proti smeru hodinových ručičiek</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Otočiť výber v smere hodinových ručičiek</translation>
    </message>
    <message>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation type="vanished">Mierka premietania v pôvodnej veľkosti (&apos;izometrický výkres&apos;)</translation>
    </message>
    <message>
        <source>True scale</source>
        <translation type="vanished">Skutočná mierka</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Izometrický Pohľad</translation>
    </message>
    <message>
        <location filename="../IsoProject.js" line="+50"/>
        <source>Isometric</source>
        <translation>Izometricky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Isometric True Scale</source>
        <translation>Izometrická pravá mierka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Planometric</source>
        <translation>Planometricky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimetric</source>
        <translation>Dimetricky</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cabinet</source>
        <translation>Kabinet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cavalier</source>
        <translation>Jazdec</translation>
    </message>
</context>
</TS>
